==> centreon-web-24.04.12.tar.gz: centreon-web-24.04.12/src/Centreon/Infrastructure/FileManager/File.php <==
<?php
/*
 * Copyright 2005-2019 Centreon
 * Centreon is developed by : Julien Mathis and Romain Le Merlus under
 * GPL Licence 2.0.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation ; either version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, see <http://www.gnu.org/licenses>.
 *
 * Linking this program statically or dynamically with other modules is making a
 * combined work based on this program. Thus, the terms and conditions of the GNU
 * General Public License cover the whole combination.
 *
 * As a special exception, the copyright holders of this program give Centreon
 * permission to link this program with independent modules to produce an executable,
 * regardless of the license terms of these independent modules, and to copy and
 * distribute the resulting executable under terms of Centreon choice, provided that
 * Centreon also meet, for each linked independent module, the terms  and conditions
 * of the license of that module. An independent module is a module which is not
 * derived from this program. If you modify this program, you may extend this
 * exception to your version of the program, but you are not obliged to do so. If you
 * do not wish to do so, delete this exception statement from your version.
 *
 * For more information : contact@centreon.com
 *
 *
 */

namespace Centreon\Infrastructure\FileManager;

class File
{
    protected $name;
    protected $type;
    protected $extension;
    protected $tmp_name;
    protected $error;
    protected $size;

    public function __construct(array $data)
    {
        foreach ($data as $prop => $value) {
            $this->$prop = $value;
        }

        if ($this->name) {
            $this->extension = pathinfo($this->name, PATHINFO_EXTENSION);
        }
    }

    public function getName() : string
    {
        return $this->name;
    }

    public function getType() : string
    {
        return $this->type;
    }

    public function getExtension() : string
    {
        return $this->extension;
    }

    public function getTmpName() : string
    {
        return $this->tmp_name;
    }

    public function getError() : string
    {
        return $this->error;
    }

    public function getSize() : string
    {
        return $this->size;
    }
}

==> centreon-web-24.10.15.tar.gz: centreon-web-24.10.15/src/Centreon/Infrastructure/FileManager/File.php <==
<?php
/*
 * Copyright 2005-2019 Centreon
 * Centreon is developed by : Julien Mathis and Romain Le Merlus under
 * GPL Licence 2.0.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation ; either version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, see <http://www.gnu.org/licenses>.
 *
 * Linking this program statically or dynamically with other modules is making a
 * combined work based on this program. Thus, the terms and conditions of the GNU
 * General Public License cover the whole combination.
 *
 * As a special exception, the copyright holders of this program give Centreon
 * permission to link this program with independent modules to produce an executable,
 * regardless of the license terms of these independent modules, and to copy and
 * distribute the resulting executable under terms of Centreon choice, provided that
 * Centreon also meet, for each linked independent module, the terms  and conditions
 * of the license of that module. An independent module is a module which is not
 * derived from this program. If you modify this program, you may extend this
 * exception to your version of the program, but you are not obliged to do so. If you
 * do not wish to do so, delete this exception statement from your version.
 *
 * For more information : contact@centreon.com
 *
 *
 */

namespace Centreon\Infrastructure\FileManager;

class File
{
    protected $name;
    protected $type;
    protected $extension;
    protected $tmp_name;
    protected $error;
    protected $size;

    public function __construct(array $data)
    {
        $this->name = $data['name'] ?? '';
        $this->type = $data['type'] ?? '';
        $this->tmp_name = $data['tmp_name'] ?? '';
        $this->error = $data['error'] ?? 0;
        $this->size = $data['size'] ?? 0;
        $this->extension = $this->name ? pathinfo($this->name, PATHINFO_EXTENSION) : '';
    }

    public function getName() : string
    {
        return $this->name;
    }

    public function getType() : string
    {
        return $this->type;
    }

    public function getExtension() : string
    {
        return $this->extension;
    }

    public function getTmpName() : string
    {
        return $this->tmp_name;
    }

    public function getError(): int
    {
        return $this->error;
    }

    public function getSize(): int
    {
        return $this->size;
    }
}
